NeSy4PPM.ProbDeclmonitor package — NeSy4PPM 0.1.0 documentation

# NeSy4PPM.ProbDeclmonitor package

## Submodules

## NeSy4PPM.ProbDeclmonitor.autUtils module

class NeSy4PPM.ProbDeclmonitor.autUtils.TruthValue(value)

  Bases: `Enum`

  An enumeration.

  PERM_SAT = 1
  PERM_VIOL = 4
  POSS_SAT = 2
  POSS_VIOL = 3

NeSy4PPM.ProbDeclmonitor.autUtils.get_state_for_prefix(aut: DFA, word: Sequence[SymbolType]) → StateType

NeSy4PPM.ProbDeclmonitor.autUtils.get_state_truth_value(aut: DFA, state: StateType, activityEncodings: list[str]) → TruthValue

NeSy4PPM.ProbDeclmonitor.autUtils.prefix_to_word(prefix: list[str], activityToEncoding: dict[str, str]) → Sequence[SymbolType]

## NeSy4PPM.ProbDeclmonitor.ltlUtils module

NeSy4PPM.ProbDeclmonitor.ltlUtils.get_constraint_formula(template: DeclareModelTemplate, ac1: str, ac2: str, cardinality: int) → str

## NeSy4PPM.ProbDeclmonitor.probDeclPredictor module

class NeSy4PPM.ProbDeclmonitor.probDeclPredictor.AggregationMethod(value)

  Bases: `Enum`

  An enumeration.

  AVG = 3
  MAX = 2
  MIN = 4
  SUM = 1

class NeSy4PPM.ProbDeclmonitor.probDeclPredictor.ProbDeclarePredictor

  Bases: `object`

  loadProbDeclModel(modelPath: str) → None
  processPrefix(prefix: list[str], aggregationMethod: AggregationMethod = AggregationMethod.SUM) → dict[str | bool, float64]

NeSy4PPM.ProbDeclmonitor.probDeclPredictor.get_aggregate_score(tmpProbabilities: list[float64], aggregationMethod: AggregationMethod) → float64

## Module contents